# compas_tna

COMPAS package for Thrust Network Analaysis. This package provides the base implementation of TNA. For a RhinoVault-style user interface and workflow, see `compas-RV2`.

## Getting Started

Have a look at the "Getting Started" instructions in the docs: <https://compas-dev.github.io/compas_tna/gettingstarted.html>.

## First Steps

A good place to start exploring TNA through `compas_tna` are the [tutorial](https://compas-dev.github.io/compas_tna/tutorial.html), and the [examples](https://compas-dev.github.io/compas_tna/examples.html).

## Questions and Feedback

For questions and feedback , have a look at the [compas_tna category](https://forum.compas-framework.org/c/compas-tna) of the COMPAS forum.

## Issues

If you run into problems, please file an issue on the [issue tracker](https://github.com/compas-dev/compas_tna/issues). If we don't know it is broken, we can't fix it...

## Contributing

Guidelines for developers are under construction. However, we always accept contributions in the form of Pull Requests.

## License

`compas_tna` is licensed under the MIT License. See [LICENSE](https://github.com/compas-dev/compas_tna/blob/master/LICENSE), for more information.
